#!/bin/bash
# Installation onto $HOME/MicroBrowserSbc
APP=MicroBrowserSbc
APPDIR=${APP}
archive=MicroBrowserSbc_armhf.tgz
URL=http://ininet.ch/public/MicroBrowser/pi/${archive}
ARCH=armv7l

echo "Installation of SpiderControl ${APP} X11 for Raspberry Pi (${ARCH})"
echo "User: ${USER}"
echo "Home: ${HOME}"
echo "Installation under ${HOME}/${APPDIR}"
echo "Download: $URL"

# Integrity check
[ ! -d ${HOME} ] && { echo "Error: ${HOME} directory does not exist!"; exit 2; }
[ $(uname -s) != "Linux" ] && echo "Error: Is not Linux" && uname -a && exit -2
[ $(uname -m) != "${ARCH}" ] && echo "Error: Is not ${ARCH}" && uname -a && exit -3
[ $USER == "root" ] && echo "Error: Do not install the software as root or with sudo" && exit -4
[ `whoami` == "root" ] && echo "Error: Do not install the software as root or with sudo" && exit -4
#tbd? [ $USER != "pi" ] && { echo "Error: Install with user pi"; exit 1; }

echo -n "> Install or update SpiderControl ${APP} (Yy/n)? "
read -n 1 answer && echo ""
if [ "$answer" != "${answer#[Yy]}" ]; then
    echo "Yes"
    sleep 1
else
    echo "No" && exit 0
fi

# Create tmp directory
tmp_dir=$(mktemp -d -t mbrow-XXXXXXXXXX)
echo "temp dir is: $tmp_dir"
err=$?
if [ $err -ne 0 ] ; then
  echo "Exit on error: $err"
  exit $err
fi
cd $tmp_dir
# Check if current directory is tmp_dir
[ $PWD != $tmp_dir ] && echo "Failed to create temp directory $tmp_dir" && exit 13

# Download archive file
wget -O ${archive} $URL
ERR=$?
[ $ERR -ne 0 ] && { rm -f ${archive} && rm -rf ${tmp_dir}; echo "Exit on error $ERR"; exit ${ERR}; }

# Check if file exist and is not empty
[ ! -s ${archive} ] && { echo "Error: File not found or empty: ${archive}"; exit -15; }
echo "Extract ${archive}"
if [[ ${archive} == *".zip" ]]; then
    /bin/unzip -q ${archive}
elif [[ ${archive} == *".tar.gz" || ${archive} == *".tgz" ]]; then
    /bin/tar xzf ${archive}
elif [[ ${archive} == *".tar.bz2" || ${archive} == *".tb2" || ${archive} == *".tz2" || ${archive} == *".tbz2" ]]; then
    /bin/tar xjf ${archive}
elif [[ ${archive} == *".tar.xz" || ${archive} == *".txz" ]]; then
    /bin/tar -x --xz -f ${archive}
elif [[ ${archive} == *".tar.lzma" || ${archive} == *".tlz" ]]; then
    /bin/tar -x --lzma -f ${archive}
elif [[ ${archive} == *".tar" ]]; then
    /bin/tar xf ${archive}
else # tgz
    echo "Invalid argument: ${archive}"
    exit 22;
fi
RES=$?
[ $RES -ne 0 ] && { echo "Failed to extract ${archive}"; exit $RES; }
[ ! -d ${APPDIR} ] && { echo "${APPDIR} directory not found!"; exit 2; } || echo "done"

# Stop and disable any MicroBrowser service (if exist)
disableAutoStart()
{
    [ -f ${HOME}/.config/autostart/microbrowser_autostart.desktop ] && rm -f ${HOME}/.config/autostart/microbrowser_autostart.desktop
    [ -f /lib/systemd/system/microbrowser.service ] && echo "Stop microbrowser service" && sudo systemctl stop microbrowser && 
    sleep 1 && sudo systemctl disable microbrowser.service && echo "service stopped and disabled"
    [ -f /lib/systemd/system/microbrowser.timer ] && sudo systemctl disable microbrowser.timer && echo "timer disable"
    [ -f /etc/init.d/microbrowser ] && 
    echo "Remove /etc/init.d/microbrowser service" && { sudo update-rc.d microbrowser remove; sudo rm -f /etc/init.d/microbrowser && echo "done"; }
}

chmod 755 ${APPDIR}/${APP} ${APPDIR}/*.sh ${APPDIR}/install/*.sh

echo "Add shortcut in Desktop"
[[ -d ${HOME}/Desktop && -f ${APPDIR}/install/${APP}.desktop ]] && 
envsubst < ${APPDIR}/install/${APP}.desktop > ${HOME}/Desktop/${APP}.desktop && 
chmod 755 ${HOME}/Desktop/${APP}.desktop &&
echo "done, under:" && ls ${HOME}/Desktop/${APP}.desktop
echo ""

# Auto start stuff
echo -n "> Install Auto-Start service (Yy/Nn/Iignore)? "
read -n 1 answer && echo ""
if [ "$answer" != "${answer#[Yy]}" ]; then
    echo "Yes"
    disableAutoStart
    if [ -f ${APPDIR}/install/microbrowser_autostart.desktop ]; then
      echo "Add shortcut into ${HOME}/.config/autostart"
      # Create autostart dir if not exist
      [ ! -d ${HOME}/.config/autostart ] && mkdir ${HOME}/.config/autostart
      [ -d ${HOME}/.config/autostart ] && 
      envsubst < ${APPDIR}/install/microbrowser_autostart.desktop > ${HOME}/.config/autostart/microbrowser_autostart.desktop && 
      chmod 755 ${HOME}/.config/autostart/microbrowser_autostart.desktop &&
      echo "The ${APP} will automatically start with Linux, using file:" &&
      ls ${HOME}/.config/autostart/microbrowser_autostart.desktop || 
      echo "Error: Failed to create autostart file into ${HOME}/.config/autostart/microbrowser_autostart.desktop"
    else
      # install service
      systemctl --version
      if [ $? -eq 0 ]; then
        echo "Install systemd microbrowser.service"
        envsubst <  ${APPDIR}/install/systemd/microbrowser.service > microbrowser.service &&
        cp -f ${APPDIR}/install/systemd/microbrowser.timer  microbrowser.timer &&
        sudo mv -f microbrowser.service microbrowser.timer /lib/systemd/system/
        sudo systemctl daemon-reload &&
        sudo systemctl enable microbrowser.timer && echo "done"
      else
        echo "Install /etc/init.d/microbrowser service"
        envsubst <  ${APPDIR}/install/init/microbrowser > microbrowser &&
        sudo mv -f microbrowser /etc/init.d/
        sudo chmod 755 /etc/init.d/microbrowser &&
        sudo update-rc.d microbrowser defaults && echo "done"
      fi
    fi
elif [ "$answer" != "${answer#[Nn]}" ]; then
    echo "No Auto-Start"
    disableAutoStart
    #rm -f ${HOME}/.config/autostart/microbrowser_autostart.desktop
else
    echo "Ignored"
fi
sleep 1

# Copy xfce config files (if any)
[ -d ${APPDIR}/install/xfce4 ] && cp -f ${APPDIR}/install/xfce4/*.xml ${HOME}/.config/xfce4/xfconf/xfce-perchannel-xml/

# Copy config files
echo "Copy current settings"
FILE=${HOME}/${APPDIR}/mb_config.ini  && [ -e $FILE ] && cp -f $FILE ${APPDIR}/ && echo "Copy $FILE"
FILE=${HOME}/${APPDIR}/uBrowser.xml   && [ -e $FILE ] && cp -f $FILE ${APPDIR}/ && echo "Copy $FILE"
FILE=${HOME}/${APPDIR}/uBrowser.oem   && [ -e $FILE ] && cp -f $FILE ${APPDIR}/ && echo "Copy $FILE"
unset FILE

echo "Kill ${APP}"
pkill -f ${APP}
echo "Replace ${HOME}/${APPDIR} directory"
[ -d ${HOME}/${APPDIR}-prev~ ] && rm -rf ${HOME}/${APPDIR}-prev~
[ -d ${HOME}/${APPDIR} ] && mv -f ${HOME}/${APPDIR} ${HOME}/${APPDIR}-prev~ && echo "Move existing ${APPDIR} folder into  ${HOME}/${APPDIR}-prev~"
mv ${APPDIR} ${HOME}/ || { echo "Error: Failed to move ${APPDIR} directory?"; exit $?; }
cd ${HOME}
rm -rf $tmp_dir && echo "Remove tmp dir done" || echo "Remove tmp dir failed, errno: $?"
# Restart MicroBrowser ?
echo "--"
FILE=${HOME}/${APPDIR}/uBrowser.xml
echo "To start ${APP} in Full Screen, set the kiosk mode to 1 in the configuration file: ${FILE}"
echo " Or launch the following command line to set kiosk mode: "
echo "  sed -i 's@<kiosk>0@<kiosk>1@g' ${FILE}"
echo " Reset to 0 with:"
echo "  sed -i 's@<kiosk>1@<kiosk>0@g' ${FILE}"
echo " And check the kiosk setting with:"
echo "  cat ${FILE} | grep kiosk"
echo "Kill the ${APP} with Alt+F4 or with the command line: pkill ${APP}"
echo "--"

echo -n "> Set kiosk mode to start ${APP} in full screen (Yy/Nn/Iignore)? "
read -n 1 answer && echo ""
[ "$answer" != "${answer#[Ii]}" ] && { echo "Bye"; exit 0; }

## create config file if not exist yet, with kiosk setting
FILE=${HOME}/${APPDIR}/uBrowser.xml
[ ! -f ${FILE} ] &&
 echo "<uBrowser>" > ${FILE} &&
 echo "  <kiosk>0</kiosk>" >> ${FILE} &&
 echo "  <sip>0</sip>" >> ${FILE} &&
 echo "</uBrowser>" >> ${FILE}

if [ "$answer" != "${answer#[Yy]}" ]; then
    echo "Yes"
    sed -i 's@<kiosk>0@<kiosk>1@g' ${FILE} && echo "full screen enabled"
else
    echo "No"
    sed -i 's@<kiosk>1@<kiosk>0@g' ${FILE} && echo "full screen disabled"
fi
cat ${FILE} | grep kiosk
echo ""
